@@ -8,7 +8,9 @@ use Excel::Writer::XLSX;
 use App::Fasops -command;
 use App::Fasops::Common;
 
-use constant abstract => 'paint substitutions and indels to an excel file';
+sub abstract {
+    return 'paint substitutions and indels to an excel file';
+}
 
 sub opt_spec {
     return (
@@ -33,8 +35,13 @@ sub usage_desc {
 sub description {
     my $desc;
     $desc .= ucfirst(abstract) . ".\n";
-    $desc .= "\t<infile> are blocked fasta files, .fas.gz is supported.\n";
-    $desc .= "\tinfile == stdin means reading from STDIN\n";
+    $desc .= <<'MARKDOWN';
+
+* <infiles> are paths to axt files, .axt.gz is supported
+* infile == stdin means reading from STDIN
+
+MARKDOWN
+
     return $desc;
 }
 
